///////////////////////////////////////////////////////////////////////////////
// Name:        gui.cpp
// Purpose:     Code for NeReK's Gui
// Author:      Chad Rempp
// Modified by: Chad Rempp
// Created:     05-20-03
// Copyright:   (c) 2003 Chad Rempp
// Licence:     GNU Public License (hey it's what all my friends are doing)
///////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#include <wx/glcanvas.h>
#include "gui.h"

#ifndef WX_PRECOMP
   #include <wx/wx.h>
#endif

IMPLEMENT_APP(NGuiApp)

///////////////////////////////////////////////////////////////////////////////
// wxApp Class          NGuiApp
///////////////////////////////////////////////////////////////////////////////

bool NGuiApp::OnInit()
{
   mainFrame *main_frame = new mainFrame("NeReK Simulator",
       wxPoint (0,0), wxSize(450, 45), wxDEFAULT_FRAME_STYLE);
   main_frame->Show(TRUE);
   SetTopWindow(main_frame);

   /* Do not return FALSE or the app will terminate immediately */
   return TRUE;
}

///////////////////////////////////////////////////////////////////////////////
// wxFrame Class          mainFrame
///////////////////////////////////////////////////////////////////////////////

mainFrame::mainFrame(const wxString &title, const wxPoint &pos, const wxSize &size, long style)
    : wxFrame((wxFrame *) NULL, -1, title, pos, size, style)
{
    wxMenu *FileMenu = new wxMenu;
    wxMenu *NewMenu  = new wxMenu;
    wxMenuBar *MenuBar = new wxMenuBar;

    // create a menu bar
    FileMenu->Append(mainFrame_Quit, "&Quit");
    NewMenu->Append(mainFrame_NewPerceptron, "&Perceptron");
    NewMenu->Append(mainFrame_NewMultiPercp, "&Multi Layer Perceptron");

    // Add it to the menu bar
    MenuBar->Append(FileMenu, "&File");
    MenuBar->Append(NewMenu,"&New");
    SetMenuBar(MenuBar);

    // Create the status bar
    CreateStatusBar(2);
    SetStatusText("Welcome To NeReK");
}

void mainFrame::OnQuit(wxCommandEvent & WXUNUSED(event))
{
    // Force the window to close
    Close(TRUE);
}

void mainFrame::OnNewPerceptron(wxCommandEvent & WXUNUSED(event))
{
    netDialog *dlg_perceptron = new netDialog(this, -1, "Perceptron Simulator",
                               wxPoint(100,100), wxSize(125,250));
    dlg_perceptron->Show();
}

void mainFrame::OnNewMultiPercp(wxCommandEvent & WXUNUSED(event))
{
}

BEGIN_EVENT_TABLE(mainFrame, wxFrame)
   EVT_MENU(mainFrame_Quit, mainFrame::OnQuit)
   EVT_MENU(mainFrame_NewPerceptron, mainFrame::OnNewPerceptron)
   EVT_MENU(mainFrame_NewMultiPercp, mainFrame::OnNewMultiPercp)
END_EVENT_TABLE()

///////////////////////////////////////////////////////////////////////////////
// wxDialog Class          netDialog
///////////////////////////////////////////////////////////////////////////////

netDialog::netDialog(wxWindow *parent, wxWindowID id, const wxString &title,
                     const wxPoint &position, const wxSize& size, long style) :
                     wxDialog(parent, id, title, position, size, style)
{
    btn_newinput  = new wxButton(this, netDialog_NEWINPUT_BTN, "New Input", wxPoint(10,10), wxSize(70,17));
    btn_delinput  = new wxButton(this, netDialog_DELINPUT_BTN, "Delete Input", wxPoint(10,30), wxSize(70,17));
    btn_setwghts  = new wxButton(this, netDialog_SETWGHTS_BTN, "Set Weights", wxPoint(10,50), wxSize(70,17));
    btn_train     = new wxButton(this, netDialog_TRAIN_BTN, "Train", wxPoint(10,90), wxSize(70,17));
    btn_run       = new wxButton(this, netDialog_RUN_BTN, "Run", wxPoint(10,110), wxSize(70,17));
    btn_setdesrd  = new wxButton(this, netDialog_SETDESRD_BTN, "Set Desired", wxPoint(10,70), wxSize(70,17));
    btn_showdiag  = new wxButton(this, netDialog_SHOWDIAG_BTN, "Show Diag", wxPoint(10,170), wxSize(70,17));
    btn_quit      = new wxButton(this, netDialog_QUIT_BTN, "Quit", wxPoint(10,200), wxSize(70,17));
    txt_bias      = new wxTextCtrl(this, netDialog_BIAS_TXT, "", wxPoint(90,150), wxSize(25,22));
    txt_squashval = new wxTextCtrl(this, netDialog_SQUASHVAL_TXT, "", wxPoint(90,130), wxSize(25,22));
    stc_bias      = new wxStaticText(this, -1, "Bias Value", wxPoint(10,150));
    stc_squashval = new wxStaticText(this, -1, "Squash Value", wxPoint(10,130));
}

void netDialog::OnNewInput(wxCommandEvent &event)
{
}

void netDialog::OnDelInput(wxCommandEvent &event)
{
}

void netDialog::OnSetWghts(wxCommandEvent &event)
{
}

void netDialog::OnSetDesrd(wxCommandEvent &event)
{
}

void netDialog::OnTrain(wxCommandEvent &event)
{
}

void netDialog::OnRun(wxCommandEvent &event)
{
}

void netDialog::OnShowDiag(wxCommandEvent &event)
{
    wxFrame *dlg_gldiagram = new wxFrame(this, -1, "Network Diagram",
                               wxPoint(50,50), wxSize(450,340));
    wxGLCanvas *glc_netdiag = new wxGLCanvas(dlg_gldiagram, -1, wxPoint(0,0), wxSize(200,200));
    dlg_gldiagram->Show(TRUE);
    glc_netdiag->SetCurrent();

    glClearColor(0.0, 0.0, 0.0, 0.0);
    glViewport(0, 0, (GLint)200, (GLint)200);
    glColor3f(1.0, 1.0, 1.0);
    glBegin(GL_POLYGON);
      glVertex2f(-0.5, -0.5);
      glVertex2f(-0.5, 0.5);
      glVertex2f(0.5, 0.5);
      glVertex2f(0.5, -0.5);
    glEnd();
    glFlush();

    glc_netdiag->SwapBuffers();
}

void netDialog::OnQuit(wxCommandEvent &event)
{
    Close(TRUE);
}

BEGIN_EVENT_TABLE(netDialog, wxDialog)
   EVT_BUTTON(netDialog_NEWINPUT_BTN, netDialog::OnNewInput)
   EVT_BUTTON(netDialog_DELINPUT_BTN, netDialog::OnDelInput)
   EVT_BUTTON(netDialog_SETWGHTS_BTN, netDialog::OnSetWghts)
   EVT_BUTTON(netDialog_TRAIN_BTN, netDialog::OnTrain)
   EVT_BUTTON(netDialog_RUN_BTN, netDialog::OnRun)
   EVT_BUTTON(netDialog_SETDESRD_BTN, netDialog::OnSetDesrd)
   EVT_BUTTON(netDialog_SHOWDIAG_BTN, netDialog::OnShowDiag)
   EVT_BUTTON(netDialog_QUIT_BTN, netDialog::OnQuit)
END_EVENT_TABLE()


